@@ -2,7 +2,7 @@ package Catalyst::Controller::HTML::FormFu::Action::Form;
 
 use strict;
 use warnings;
-use base qw( Catalyst::Action );
+use base qw( Catalyst::Controller::HTML::FormFu::ActionBase::Form );
 
 use Config::Any;
 use MRO::Compat;
@@ -11,6 +11,11 @@ sub execute {
     my $self = shift;
     my ( $controller, $c ) = @_;
 
+    if ( $self->reverse =~ $self->_form_action_regex ) {
+        # don't load form again
+        return $self->next::method(@_);
+    }
+
     my $config = $controller->_html_formfu_config;
 
     return $self->next::method(@_)
